==> eaimxrt1062_4mb_sdk_2_12_1_2022-11-18.zip: middleware/maestro/docs/src/files_dup.js <==
var files_dup =
[
    [ "error.h", "error_8h.html", "error_8h" ],
    [ "file_utils.h", "file__utils_8h.html", "file__utils_8h" ],
    [ "general_utils.h", "general__utils_8h.html", "general__utils_8h" ],
    [ "logging.h", "logging_8h.html", "logging_8h" ],
    [ "ringbuffer.h", "ringbuffer_8h.html", "ringbuffer_8h" ],
    [ "streamer_api.h", "streamer__api_8h.html", "streamer__api_8h" ],
    [ "streamer_element_properties.h", "streamer__element__properties_8h.html", "streamer__element__properties_8h" ],
    [ "streamer_message.h", "streamer__message_8h.html", "streamer__message_8h" ],
    [ "streamer_pcm.h", "streamer__pcm_8h.html", "streamer__pcm_8h" ],
    [ "cci_metadata.h", "cci__metadata_8h.html", "cci__metadata_8h" ],
    [ "codec_interface.h", "codec__interface_8h.html", "codec__interface_8h" ],
    [ "codec_interface_public_api.h", "codec__interface__public__api_8h.html", "codec__interface__public__api_8h" ],
    [ "errordefs.h", "errordefs_8h.html", "errordefs_8h" ],
    [ "pad.c", "pad_8c.html", "pad_8c" ],
    [ "pad.h", "pad_8h.html", "pad_8h" ],
    [ "pipeline.c", "pipeline_8c.html", "pipeline_8c" ],
    [ "pipeline.h", "pipeline_8h.html", "pipeline_8h" ],
    [ "streamer.c", "streamer_8c.html", "streamer_8c" ],
    [ "streamer.h", "streamer_8h.html", "streamer_8h" ],
    [ "streamer_element.c", "streamer__element_8c.html", "streamer__element_8c" ],
    [ "streamer_element.h", "streamer__element_8h.html", "streamer__element_8h" ],
    [ "streamer_msg.c", "streamer__msg_8c.html", "streamer__msg_8c" ],
    [ "ccidec.c", "ccidec_8c.html", "ccidec_8c" ],
    [ "ccidec.h", "ccidec_8h.html", "ccidec_8h" ],
    [ "codec_interface.c", "codec__interface_8c.html", "codec__interface_8c" ],
    [ "codecextractmetadata.c", "codecextractmetadata_8c.html", "codecextractmetadata_8c" ],
    [ "audio_sink_pcmrtos.c", "audio__sink__pcmrtos_8c.html", "audio__sink__pcmrtos_8c" ],
    [ "audio_sink_pcmrtos.h", "audio__sink__pcmrtos_8h.html", "audio__sink__pcmrtos_8h" ],
    [ "audio_src_pcmrtos.c", "audio__src__pcmrtos_8c.html", "audio__src__pcmrtos_8c" ],
    [ "audio_src_pcmrtos.h", "audio__src__pcmrtos_8h.html", "audio__src__pcmrtos_8h" ],
    [ "audio_sink.c", "audio__sink_8c.html", "audio__sink_8c" ],
    [ "audio_sink.h", "audio__sink_8h.html", "audio__sink_8h" ],
    [ "audio_src.c", "audio__src_8c.html", "audio__src_8c" ],
    [ "audio_src.h", "audio__src_8h.html", "audio__src_8h" ],
    [ "decoder.c", "decoder_8c.html", "decoder_8c" ],
    [ "decoder.h", "decoder_8h.html", "decoder_8h" ],
    [ "decoder_pads.c", "decoder__pads_8c.html", "decoder__pads_8c" ],
    [ "decoder_pads.h", "decoder__pads_8h.html", "decoder__pads_8h" ],
    [ "eap.c", "eap_8c.html", "eap_8c" ],
    [ "eap.h", "eap_8h.html", "eap_8h" ],
    [ "file_sink.c", "file__sink_8c.html", "file__sink_8c" ],
    [ "file_sink.h", "file__sink_8h.html", "file__sink_8h" ],
    [ "file_src_freertos.c", "file__src__freertos_8c.html", "file__src__freertos_8c" ],
    [ "file_src_freertos.h", "file__src__freertos_8h.html", "file__src__freertos_8h" ],
    [ "mem_sink.c", "mem__sink_8c.html", "mem__sink_8c" ],
    [ "mem_sink.h", "mem__sink_8h.html", "mem__sink_8h" ],
    [ "mem_src.c", "mem__src_8c.html", "mem__src_8c" ],
    [ "mem_src.h", "mem__src_8h.html", "mem__src_8h" ],
    [ "netbuf_src.c", "netbuf__src_8c.html", "netbuf__src_8c" ],
    [ "netbuf_src.h", "netbuf__src_8h.html", "netbuf__src_8h" ],
    [ "vit_sink.c", "vit__sink_8c.html", "vit__sink_8c" ],
    [ "vit_sink.h", "vit__sink_8h.html", "vit__sink_8h" ],
    [ "cei.h", "cei_8h.html", "cei_8h" ],
    [ "cei_enctypes.h", "cei__enctypes_8h.html", "cei__enctypes_8h" ],
    [ "cei_table.h", "cei__table_8h.html", "cei__table_8h" ],
    [ "cci_codec_type_conversion.c", "cci__codec__type__conversion_8c.html", "cci__codec__type__conversion_8c" ],
    [ "streamer_audiosrc.c", "streamer__audiosrc_8c.html", "streamer__audiosrc_8c" ],
    [ "streamer_audiosrc.h", "streamer__audiosrc_8h.html", "streamer__audiosrc_8h" ],
    [ "streamer_fs.c", "streamer__fs_8c.html", "streamer__fs_8c" ],
    [ "streamer_fs.h", "streamer__fs_8h.html", "streamer__fs_8h" ],
    [ "streamer_mic2file.h", "streamer__mic2file_8h.html", "streamer__mic2file_8h" ],
    [ "streamer_opusmem2mem.c", "streamer__opusmem2mem_8c.html", "streamer__opusmem2mem_8c" ],
    [ "streamer_opusmem2mem.h", "streamer__opusmem2mem_8h.html", "streamer__opusmem2mem_8h" ],
    [ "file_utils.c", "file__utils_8c.html", "file__utils_8c" ],
    [ "general_utils.c", "general__utils_8c.html", "general__utils_8c" ],
    [ "ringbuffer.c", "ringbuffer_8c.html", "ringbuffer_8c" ]
];

==> eaimxrt1062_16mb_sdk_2_15_000_2024-03-12.zip: middleware/maestro/docs/src/files_dup.js <==
var files_dup =
[
    [ "audio_proc.c", "audio__proc_8c.html", "audio__proc_8c" ],
    [ "audio_proc.h", "audio__proc_8h.html", "audio__proc_8h" ],
    [ "audio_sink.c", "audio__sink_8c.html", "audio__sink_8c" ],
    [ "audio_sink.h", "audio__sink_8h.html", "audio__sink_8h" ],
    [ "audio_sink_pcmrtos.c", "audio__sink__pcmrtos_8c.html", "audio__sink__pcmrtos_8c" ],
    [ "audio_sink_pcmrtos.h", "audio__sink__pcmrtos_8h.html", "audio__sink__pcmrtos_8h" ],
    [ "audio_src.c", "audio__src_8c.html", "audio__src_8c" ],
    [ "audio_src.h", "audio__src_8h.html", "audio__src_8h" ],
    [ "audio_src_pcmrtos.c", "audio__src__pcmrtos_8c.html", "audio__src__pcmrtos_8c" ],
    [ "audio_src_pcmrtos.h", "audio__src__pcmrtos_8h.html", "audio__src__pcmrtos_8h" ],
    [ "cci_codec_type_conversion.c", "cci__codec__type__conversion_8c.html", "cci__codec__type__conversion_8c" ],
    [ "cci_metadata.h", "cci__metadata_8h.html", "cci__metadata_8h" ],
    [ "ccidec.c", "ccidec_8c.html", "ccidec_8c" ],
    [ "ccidec.h", "ccidec_8h.html", "ccidec_8h" ],
    [ "cei.h", "cei_8h.html", "cei_8h" ],
    [ "cei_enctypes.h", "cei__enctypes_8h.html", "cei__enctypes_8h" ],
    [ "cei_table.h", "cei__table_8h.html", "cei__table_8h" ],
    [ "codec_interface.c", "codec__interface_8c.html", "codec__interface_8c" ],
    [ "codec_interface.h", "codec__interface_8h.html", "codec__interface_8h" ],
    [ "codec_interface_public_api.h", "codec__interface__public__api_8h.html", "codec__interface__public__api_8h" ],
    [ "codecextractmetadata.c", "codecextractmetadata_8c.html", "codecextractmetadata_8c" ],
    [ "decoder.c", "decoder_8c.html", "decoder_8c" ],
    [ "decoder.h", "decoder_8h.html", "decoder_8h" ],
    [ "decoder_pads.c", "decoder__pads_8c.html", "decoder__pads_8c" ],
    [ "decoder_pads.h", "decoder__pads_8h.html", "decoder__pads_8h" ],
    [ "error.h", "error_8h.html", "error_8h" ],
    [ "errordefs.h", "errordefs_8h.html", "errordefs_8h" ],
    [ "file_sink.c", "file__sink_8c.html", "file__sink_8c" ],
    [ "file_sink.h", "file__sink_8h.html", "file__sink_8h" ],
    [ "file_src_freertos.c", "file__src__freertos_8c.html", "file__src__freertos_8c" ],
    [ "file_src_freertos.h", "file__src__freertos_8h.html", "file__src__freertos_8h" ],
    [ "file_utils.c", "file__utils_8c.html", "file__utils_8c" ],
    [ "file_utils.h", "file__utils_8h.html", "file__utils_8h" ],
    [ "general_utils.c", "general__utils_8c.html", "general__utils_8c" ],
    [ "general_utils.h", "general__utils_8h.html", "general__utils_8h" ],
    [ "LVC_Types.h", "LVC__Types_8h.html", "LVC__Types_8h" ],
    [ "maestro_logging.h", "maestro__logging_8h.html", "maestro__logging_8h" ],
    [ "mem_sink.c", "mem__sink_8c.html", "mem__sink_8c" ],
    [ "mem_sink.h", "mem__sink_8h.html", "mem__sink_8h" ],
    [ "mem_src.c", "mem__src_8c.html", "mem__src_8c" ],
    [ "mem_src.h", "mem__src_8h.html", "mem__src_8h" ],
    [ "netbuf_src.c", "netbuf__src_8c.html", "netbuf__src_8c" ],
    [ "netbuf_src.h", "netbuf__src_8h.html", "netbuf__src_8h" ],
    [ "pad.c", "pad_8c.html", "pad_8c" ],
    [ "pad.h", "pad_8h.html", "pad_8h" ],
    [ "pipeline.c", "pipeline_8c.html", "pipeline_8c" ],
    [ "pipeline.h", "pipeline_8h.html", "pipeline_8h" ],
    [ "ringbuffer.c", "ringbuffer_8c.html", "ringbuffer_8c" ],
    [ "ringbuffer.h", "ringbuffer_8h.html", "ringbuffer_8h" ],
    [ "streamer.c", "streamer_8c.html", "streamer_8c" ],
    [ "streamer.h", "streamer_8h.html", "streamer_8h" ],
    [ "streamer_api.h", "streamer__api_8h.html", "streamer__api_8h" ],
    [ "streamer_element.c", "streamer__element_8c.html", "streamer__element_8c" ],
    [ "streamer_element.h", "streamer__element_8h.html", "streamer__element_8h" ],
    [ "streamer_element_properties.h", "streamer__element__properties_8h.html", "streamer__element__properties_8h" ],
    [ "streamer_message.h", "streamer__message_8h.html", "streamer__message_8h" ],
    [ "streamer_msg.c", "streamer__msg_8c.html", "streamer__msg_8c" ],
    [ "vit_sink.c", "vit__sink_8c.html", "vit__sink_8c" ],
    [ "vit_sink.h", "vit__sink_8h.html", "vit__sink_8h" ]
];
